module Gargantext.Utils.QueryString where

import Data.Array
import Data.Map as Map
import Data.Maybe
import Data.String.Common (joinWith)
import Data.Tuple (Tuple(..))

import Gargantext.Prelude

type QueryS = Map.Map String String

queryParam :: forall a. Show a => String -> a -> QueryS
queryParam key value = Map.singleton key $ show value

queryParamS :: String -> String -> QueryS
queryParamS key value = Map.singleton key value

mQueryParam :: forall a. Show a => String -> Maybe a -> QueryS
mQueryParam _ Nothing = Map.empty
mQueryParam key (Just v) = queryParam key v

mQueryParamS :: forall a. String -> (a -> String) -> Maybe a -> QueryS
mQueryParamS _ _ Nothing = Map.empty
mQueryParamS key mFunc (Just v) = queryParamS key $ mFunc v

mQueryParamS' :: String -> Maybe String -> QueryS
mQueryParamS' _ Nothing = Map.empty
mQueryParamS' key (Just v) = queryParamS key v

joinQueryStrings :: QueryS -> String
joinQueryStrings qs =
  case (joinWith "&" $ (\(Tuple k v) -> k <> "=" <> v) <$> Map.toUnfoldable qs) of
    "" -> ""
    s  -> "?" <> s
